@@ -53,6 +53,16 @@ class Context(BaseModel):
     name: str
 
 
+class PromptVariable(BaseModel):
+    """Model for assistant prompt variables."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    key: str
+    description: Optional[str] = None
+    default_value: str
+
+
 class MCPServerConfig(BaseModel):
     """
     Configuration for an MCP server.
@@ -95,6 +105,13 @@ class MCPServerConfig(BaseModel):
     auth_token: Optional[str] = Field(
         None, description="Authentication token for the MCP-Connect server"
     )
+    single_usage: bool = Field(
+        False,
+        description="Whether this MCP server configuration is for single use only",
+    )
+    tools: Optional[list[str]] = Field(
+        None, description="List of tool names available in this MCP server"
+    )
 
 
 class MCPServerDetails(BaseModel):
@@ -103,13 +120,17 @@ class MCPServerDetails(BaseModel):
     name: str
     description: Optional[str]
     enabled: bool
+    mcp_config_id: Optional[str] = None
     config: Optional[MCPServerConfig] = None
     mcp_connect_url: Optional[str] = None
     tools_tokens_size_limit: Optional[int] = None
     command: Optional[str] = None
     arguments: Optional[str] = None
     settings: Optional[Integration] = None
+    integration_alias: Optional[str] = None
     mcp_connect_auth_token: Optional[Integration] = None
+    resolve_dynamic_values_in_arguments: bool = False
+    tools: Optional[list[str]] = None
 
 
 class SystemPromptHistory(BaseModel):
@@ -137,6 +158,17 @@ class AssistantBase(BaseModel):
     icon_url: Optional[str] = None
 
 
+class AssistantListResponse(BaseModel):
+    """Model for assistant list response."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    id: str
+    name: str
+    slug: Optional[str] = None
+    created_by: Optional[User] = None
+
+
 class Assistant(AssistantBase):
     """Full assistant model with additional fields."""
 
@@ -165,6 +197,7 @@ class Assistant(AssistantBase):
     mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
     assistant_ids: List[str] = Field(default_factory=list)
     version_count: Optional[int] = None
+    prompt_variables: Optional[List[PromptVariable]] = Field(default=None)
 
 
 class AssistantRequestBase(AssistantBase):
@@ -192,6 +225,8 @@ class AssistantRequestBase(AssistantBase):
     top_p: Optional[float] = None
     mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
     assistant_ids: List[str] = Field(default_factory=list)
+    prompt_variables: List[PromptVariable] = Field(default_factory=list)
+    skip_integration_validation: Optional[bool] = Field(default=False)
 
 
 class AssistantCreateRequest(AssistantRequestBase):
@@ -206,6 +241,92 @@ class AssistantUpdateRequest(AssistantRequestBase):
     pass
 
 
+class MissingIntegration(BaseModel):
+    """Model representing a single missing tool credential."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    toolkit: str = Field(..., description="Toolkit name (e.g., 'Data Management')")
+    tool: str = Field(..., description="Tool name (e.g., 'sql')")
+    label: str = Field(..., description="Display label for the tool (e.g., 'SQL')")
+    credential_type: Optional[str] = Field(
+        None, description="Credential type required (e.g., 'AWS', 'Jira')"
+    )
+
+
+class MissingIntegrationsByCredentialType(BaseModel):
+    """Model representing missing tools grouped by credential type."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    credential_type: str = Field(
+        ..., description="Credential type (e.g., 'AWS', 'Jira', 'Confluence')"
+    )
+    missing_tools: List[MissingIntegration] = Field(
+        ..., description="List of missing tools requiring this credential type"
+    )
+    # Optional sub-assistant context
+    assistant_id: Optional[str] = Field(
+        None, description="Sub-assistant ID (if from sub-assistant)"
+    )
+    assistant_name: Optional[str] = Field(
+        None, description="Sub-assistant name (if from sub-assistant)"
+    )
+    icon_url: Optional[str] = Field(
+        None, description="Sub-assistant icon URL (if from sub-assistant)"
+    )
+
+
+class IntegrationValidationResult(BaseModel):
+    """Complete validation result for assistant integrations."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    has_missing_integrations: bool = Field(
+        ..., description="Whether any integrations are missing"
+    )
+    missing_by_credential_type: List[MissingIntegrationsByCredentialType] = Field(
+        default_factory=list,
+        description="Missing tools in main assistant grouped by credential type",
+    )
+    sub_assistants_missing: List[MissingIntegrationsByCredentialType] = Field(
+        default_factory=list,
+        description="Missing tools in sub-assistants grouped by credential type",
+    )
+    message: Optional[str] = Field(
+        None, description="User-friendly message about missing integrations"
+    )
+
+
+class AssistantCreateResponse(BaseModel):
+    """Response model for assistant creation with validation."""
+
+    model_config = ConfigDict(extra="ignore", populate_by_name=True)
+
+    message: str = Field(..., description="Response message")
+    assistant_id: Optional[str] = Field(
+        None,
+        alias="assistantId",
+        description="Created assistant ID (None if validation failed)",
+    )
+    validation: Optional[IntegrationValidationResult] = Field(
+        None,
+        description="Validation result (populated if validation found missing integrations)",
+    )
+
+
+class AssistantUpdateResponse(BaseModel):
+    """Response model for assistant update with validation."""
+
+    model_config = ConfigDict(extra="ignore")
+
+    message: str = Field(..., description="Response message")
+    validation: Optional[IntegrationValidationResult] = Field(
+        None,
+        description="Validation result (populated if validation found missing integrations)",
+    )
+
+
 class AssistantVersion(BaseModel):
     """Immutable snapshot of assistant configuration for a specific version."""
 
@@ -224,6 +345,7 @@ class AssistantVersion(BaseModel):
     toolkits: List[ToolKitDetails] = Field(default_factory=list)
     mcp_servers: List[MCPServerDetails] = Field(default_factory=list)
     assistant_ids: List[str] = Field(default_factory=list)
+    prompt_variables: List[PromptVariable] = Field(default_factory=list)
 
 
 class ChatRole(str, Enum):
